package net.lingala.zip4j.tasks;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.io.RandomAccessFile;
import java.nio.charset.Charset;
import java.util.List;
import net.lingala.zip4j.exception.ZipException;
import net.lingala.zip4j.headers.HeaderSignature;
import net.lingala.zip4j.headers.HeaderWriter;
import net.lingala.zip4j.model.EndOfCentralDirectoryRecord;
import net.lingala.zip4j.model.FileHeader;
import net.lingala.zip4j.model.Zip4jConfig;
import net.lingala.zip4j.model.Zip64EndOfCentralDirectoryLocator;
import net.lingala.zip4j.model.Zip64EndOfCentralDirectoryRecord;
import net.lingala.zip4j.model.ZipModel;
import net.lingala.zip4j.model.enums.RandomAccessFileMode;
import net.lingala.zip4j.progress.ProgressMonitor;
import net.lingala.zip4j.tasks.AsyncZipTask;
import net.lingala.zip4j.util.FileUtils;
import net.lingala.zip4j.util.RawIO;
/* loaded from: classes.dex */
public class MergeSplitZipFileTask extends AsyncZipTask<MergeSplitZipFileTaskParameters> {
    private final RawIO rawIO;
    private final ZipModel zipModel;

    /* loaded from: classes.dex */
    public static class MergeSplitZipFileTaskParameters extends AbstractZipTaskParameters {
        private File outputZipFile;

        public MergeSplitZipFileTaskParameters(File file, Zip4jConfig zip4jConfig) {
            super(zip4jConfig);
            this.outputZipFile = file;
        }
    }

    public MergeSplitZipFileTask(ZipModel zipModel, AsyncZipTask.AsyncTaskParameters asyncTaskParameters) {
        super(asyncTaskParameters);
        this.rawIO = new RawIO();
        this.zipModel = zipModel;
    }

    private RandomAccessFile createSplitZipFileStream(ZipModel zipModel, int i) throws FileNotFoundException {
        return new RandomAccessFile(getNextSplitZipFile(zipModel, i), RandomAccessFileMode.READ.getValue());
    }

    private File getNextSplitZipFile(ZipModel zipModel, int i) {
        if (i == zipModel.getEndOfCentralDirectoryRecord().getNumberOfThisDisk()) {
            return zipModel.getZipFile();
        }
        String str = i >= 9 ? ".z" : ".z0";
        String path = zipModel.getZipFile().getPath();
        return new File(zipModel.getZipFile().getPath().substring(0, path.lastIndexOf(".")) + str + (i + 1));
    }

    private void updateFileHeaderOffsetsForIndex(List<FileHeader> list, long j, int i, int i2) {
        for (FileHeader fileHeader : list) {
            if (fileHeader.getDiskNumberStart() == i) {
                fileHeader.setOffsetLocalHeader((fileHeader.getOffsetLocalHeader() + j) - i2);
                fileHeader.setDiskNumberStart(0);
            }
        }
    }

    private void updateHeadersForMergeSplitFileAction(ZipModel zipModel, long j, OutputStream outputStream, Charset charset) throws IOException, CloneNotSupportedException {
        ZipModel zipModel2 = (ZipModel) zipModel.clone();
        zipModel2.getEndOfCentralDirectoryRecord().setOffsetOfStartOfCentralDirectory(j);
        updateSplitZipModel(zipModel2, j);
        new HeaderWriter().finalizeZipFileWithoutValidations(zipModel2, outputStream, charset);
    }

    private void updateSplitEndCentralDirectory(ZipModel zipModel) {
        int size = zipModel.getCentralDirectory().getFileHeaders().size();
        EndOfCentralDirectoryRecord endOfCentralDirectoryRecord = zipModel.getEndOfCentralDirectoryRecord();
        endOfCentralDirectoryRecord.setNumberOfThisDisk(0);
        endOfCentralDirectoryRecord.setNumberOfThisDiskStartOfCentralDir(0);
        endOfCentralDirectoryRecord.setTotalNumberOfEntriesInCentralDirectory(size);
        endOfCentralDirectoryRecord.setTotalNumberOfEntriesInCentralDirectoryOnThisDisk(size);
    }

    private void updateSplitZip64EndCentralDirLocator(ZipModel zipModel, long j) {
        if (zipModel.getZip64EndOfCentralDirectoryLocator() == null) {
            return;
        }
        Zip64EndOfCentralDirectoryLocator zip64EndOfCentralDirectoryLocator = zipModel.getZip64EndOfCentralDirectoryLocator();
        zip64EndOfCentralDirectoryLocator.setNumberOfDiskStartOfZip64EndOfCentralDirectoryRecord(0);
        zip64EndOfCentralDirectoryLocator.setOffsetZip64EndOfCentralDirectoryRecord(zip64EndOfCentralDirectoryLocator.getOffsetZip64EndOfCentralDirectoryRecord() + j);
        zip64EndOfCentralDirectoryLocator.setTotalNumberOfDiscs(1);
    }

    private void updateSplitZip64EndCentralDirRec(ZipModel zipModel, long j) {
        if (zipModel.getZip64EndOfCentralDirectoryRecord() == null) {
            return;
        }
        Zip64EndOfCentralDirectoryRecord zip64EndOfCentralDirectoryRecord = zipModel.getZip64EndOfCentralDirectoryRecord();
        zip64EndOfCentralDirectoryRecord.setNumberOfThisDisk(0);
        zip64EndOfCentralDirectoryRecord.setNumberOfThisDiskStartOfCentralDirectory(0);
        zip64EndOfCentralDirectoryRecord.setTotalNumberOfEntriesInCentralDirectoryOnThisDisk(zipModel.getEndOfCentralDirectoryRecord().getTotalNumberOfEntriesInCentralDirectory());
        zip64EndOfCentralDirectoryRecord.setOffsetStartCentralDirectoryWRTStartDiskNumber(zip64EndOfCentralDirectoryRecord.getOffsetStartCentralDirectoryWRTStartDiskNumber() + j);
    }

    private void updateSplitZipModel(ZipModel zipModel, long j) {
        zipModel.setSplitArchive(false);
        updateSplitEndCentralDirectory(zipModel);
        if (zipModel.isZip64Format()) {
            updateSplitZip64EndCentralDirLocator(zipModel, j);
            updateSplitZip64EndCentralDirRec(zipModel, j);
        }
    }

    @Override // net.lingala.zip4j.tasks.AsyncZipTask
    protected ProgressMonitor.Task getTask() {
        return ProgressMonitor.Task.MERGE_ZIP_FILES;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // net.lingala.zip4j.tasks.AsyncZipTask
    public long calculateTotalWork(MergeSplitZipFileTaskParameters mergeSplitZipFileTaskParameters) {
        long j = 0;
        if (this.zipModel.isSplitArchive()) {
            for (int i = 0; i <= this.zipModel.getEndOfCentralDirectoryRecord().getNumberOfThisDisk(); i++) {
                j += getNextSplitZipFile(this.zipModel, i).length();
            }
            return j;
        }
        return 0L;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* JADX WARN: Removed duplicated region for block: B:21:0x005c A[Catch: all -> 0x0050, TRY_LEAVE, TryCatch #9 {all -> 0x0050, blocks: (B:13:0x0038, B:21:0x005c, B:16:0x004c), top: B:78:0x0038 }] */
    /* JADX WARN: Removed duplicated region for block: B:27:0x008e  */
    /* JADX WARN: Removed duplicated region for block: B:28:0x0090  */
    /* JADX WARN: Removed duplicated region for block: B:41:0x00bb A[Catch: all -> 0x00bf, TRY_ENTER, TRY_LEAVE, TryCatch #3 {all -> 0x00e6, blocks: (B:31:0x00a3, B:46:0x00c4, B:47:0x00c5, B:51:0x00de, B:52:0x00e5, B:41:0x00bb), top: B:72:0x001f }] */
    @Override // net.lingala.zip4j.tasks.AsyncZipTask
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void executeTask(MergeSplitZipFileTaskParameters mergeSplitZipFileTaskParameters, ProgressMonitor progressMonitor) throws IOException {
        FileOutputStream fileOutputStream;
        RandomAccessFile randomAccessFile;
        Throwable th;
        int i;
        if (this.zipModel.isSplitArchive()) {
            try {
                FileOutputStream fileOutputStream2 = new FileOutputStream(mergeSplitZipFileTaskParameters.outputZipFile);
                try {
                    int numberOfThisDisk = this.zipModel.getEndOfCentralDirectoryRecord().getNumberOfThisDisk();
                    try {
                        if (numberOfThisDisk > 0) {
                            long j = 0;
                            long j2 = 0;
                            int i2 = 0;
                            int i3 = 0;
                            while (i3 <= numberOfThisDisk) {
                                RandomAccessFile createSplitZipFileStream = createSplitZipFileStream(this.zipModel, i3);
                                try {
                                    long length = createSplitZipFileStream.length();
                                    int i4 = 4;
                                    try {
                                        try {
                                            if (i3 == 0) {
                                                try {
                                                    if (this.rawIO.readIntLittleEndian(createSplitZipFileStream) != HeaderSignature.SPLIT_ZIP.getValue()) {
                                                        createSplitZipFileStream.seek(j);
                                                    } else {
                                                        i = 4;
                                                        if (i3 == numberOfThisDisk) {
                                                            length = this.zipModel.getEndOfCentralDirectoryRecord().getOffsetOfStartOfCentralDirectory();
                                                        }
                                                        long j3 = length;
                                                        long j4 = i4;
                                                        randomAccessFile = createSplitZipFileStream;
                                                        FileUtils.copyFile(createSplitZipFileStream, fileOutputStream2, j4, j3, progressMonitor, mergeSplitZipFileTaskParameters.zip4jConfig.getBufferSize());
                                                        j2 += j3 - j4;
                                                        int i5 = i3;
                                                        long j5 = j;
                                                        int i6 = numberOfThisDisk;
                                                        FileOutputStream fileOutputStream3 = fileOutputStream2;
                                                        updateFileHeaderOffsetsForIndex(this.zipModel.getCentralDirectory().getFileHeaders(), i3 != 0 ? j : j2, i5, i);
                                                        verifyIfTaskIsCancelled();
                                                        randomAccessFile.close();
                                                        i3 = i5 + 1;
                                                        numberOfThisDisk = i6;
                                                        fileOutputStream2 = fileOutputStream3;
                                                        j = j5;
                                                        i2 = i;
                                                    }
                                                } catch (Throwable th2) {
                                                    th = th2;
                                                    randomAccessFile = createSplitZipFileStream;
                                                    if (randomAccessFile != null) {
                                                    }
                                                    throw th;
                                                }
                                            }
                                            updateFileHeaderOffsetsForIndex(this.zipModel.getCentralDirectory().getFileHeaders(), i3 != 0 ? j : j2, i5, i);
                                            verifyIfTaskIsCancelled();
                                            randomAccessFile.close();
                                            i3 = i5 + 1;
                                            numberOfThisDisk = i6;
                                            fileOutputStream2 = fileOutputStream3;
                                            j = j5;
                                            i2 = i;
                                        } catch (Throwable th3) {
                                            th = th3;
                                            th = th;
                                            if (randomAccessFile != null) {
                                                randomAccessFile.close();
                                            }
                                            throw th;
                                        }
                                        FileUtils.copyFile(createSplitZipFileStream, fileOutputStream2, j4, j3, progressMonitor, mergeSplitZipFileTaskParameters.zip4jConfig.getBufferSize());
                                        j2 += j3 - j4;
                                        int i52 = i3;
                                        long j52 = j;
                                        int i62 = numberOfThisDisk;
                                        FileOutputStream fileOutputStream32 = fileOutputStream2;
                                    } catch (Throwable th4) {
                                        th = th4;
                                    }
                                    i = i2;
                                    i4 = 0;
                                    if (i3 == numberOfThisDisk) {
                                    }
                                    long j32 = length;
                                    long j42 = i4;
                                    randomAccessFile = createSplitZipFileStream;
                                } catch (Throwable th5) {
                                    th = th5;
                                    randomAccessFile = createSplitZipFileStream;
                                }
                            }
                            FileOutputStream fileOutputStream4 = fileOutputStream2;
                            updateHeadersForMergeSplitFileAction(this.zipModel, j2, fileOutputStream4, mergeSplitZipFileTaskParameters.zip4jConfig.getCharset());
                            progressMonitor.endProgressMonitor();
                            fileOutputStream4.close();
                            return;
                        }
                        throw new ZipException("zip archive not a split zip file");
                    } catch (Throwable th6) {
                        th = th6;
                        Throwable th7 = th;
                        fileOutputStream.close();
                        throw th7;
                    }
                } catch (Throwable th8) {
                    th = th8;
                    fileOutputStream = fileOutputStream2;
                }
            } catch (CloneNotSupportedException e) {
                throw new ZipException(e);
            }
        } else {
            ZipException zipException = new ZipException("archive not a split zip file");
            progressMonitor.endProgressMonitor(zipException);
            throw zipException;
        }
    }
}
